package com.example.wholeestate.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.example.wholeestate.common.resp.ResponseBean;
import com.example.wholeestate.dao.ActivityMapper;
import com.example.wholeestate.dao.BuildingMapper;
import com.example.wholeestate.model.Activity;
import com.example.wholeestate.model.Building;
import com.example.wholeestate.service.IActivityService;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * <p>
 * 活动表 服务实现类
 * </p>
 *
 * @author weiximei
 * @since 2019-03-20
 */
@Service
public class ActivityServiceImpl extends ServiceImpl<ActivityMapper, Activity> implements IActivityService {

    @Autowired
    private ActivityMapper activityMapper;

    @Autowired
    private BuildingMapper buildingMapper;

    @Override
    public ResponseBean getList(Integer pageNum, Integer pageSize, String name, Date beginDate, Date endDate) {
        ResponseBean responseBean = new ResponseBean();

        Page<Activity> page = new Page<>();
        page.setCurrent(pageNum == null ? 1 : pageNum);
        page.setSize(pageSize == null ? 10 : pageSize);
        QueryWrapper<Activity> queryWrapper = new QueryWrapper<>();
        queryWrapper.gt("status", -1);
        queryWrapper.like(StringUtils.isNotBlank(name),"title", name);
        queryWrapper.ge(null != beginDate,"begin_date", beginDate);
        queryWrapper.le(null != endDate,"end_date", endDate);
        IPage<Activity> activityIPage = activityMapper.selectPage(page, queryWrapper);
        List<Activity> records = activityIPage.getRecords();
        records.forEach(e -> {
            Integer signUpNumber = activityMapper.signUpNumber(e.getActivityId());
            e.setSignUpNumber(null == signUpNumber ? 0 : signUpNumber);
        });

        responseBean.addSuccess(activityIPage);
        return responseBean;
    }

    @Override
    public ResponseBean getActivityId(String activityId) {
        ResponseBean responseBean = new ResponseBean();

        QueryWrapper<Activity> activityQueryWrapper = new QueryWrapper<>();
        activityQueryWrapper.eq("activity_id", activityId);
        Activity activity = activityMapper.selectOne(activityQueryWrapper);
        if (null == activity) {
            responseBean.addError("活动不存在!");
            return responseBean;
        }

        QueryWrapper<Building> buildingQueryWrapper = new QueryWrapper<>();
        buildingQueryWrapper.eq("building_id", activity.getBuildingId());
        Building building = buildingMapper.selectOne(buildingQueryWrapper);
        activity.setBuilding(building);
        responseBean.addSuccess(activity);
        return responseBean;
    }

    @Override
    public ResponseBean getWxActivityList(Integer pageNum, Integer pageSize) {
        ResponseBean responseBean = new ResponseBean();

        Page<Activity> page = new Page<>();
        page.setCurrent(pageNum);
        page.setSize(pageSize);

        QueryWrapper<Activity> activityQueryWrapper = new QueryWrapper<>();
        activityQueryWrapper.eq("status", "1");
        IPage<Activity> activityIPage = activityMapper.selectPage(page, activityQueryWrapper);

        responseBean.addSuccess(activityIPage);
        return responseBean;
    }

    @Override
    public  ResponseBean getWxActivityId(String activityId) {
        ResponseBean responseBean = new ResponseBean();

        QueryWrapper<Activity> activityQueryWrapper = new QueryWrapper<>();
        activityQueryWrapper.eq("activity_id", activityId);
        Activity activity = activityMapper.selectOne(activityQueryWrapper);
        if (null == activity) {
            responseBean.addError("活动不存在!");
            return responseBean;
        }

        responseBean.addSuccess(activity);
        return responseBean;
    }
}
