package com.example.wholeestate.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.example.wholeestate.common.resp.ResponseBean;
import com.example.wholeestate.common.uuid.IdGen;
import com.example.wholeestate.dao.AppointmentMapper;
import com.example.wholeestate.dao.CustomerMapper;
import com.example.wholeestate.model.Activity;
import com.example.wholeestate.model.Appointment;
import com.example.wholeestate.model.Customer;
import com.example.wholeestate.model.Dict;
import com.example.wholeestate.service.IAppointmentService;
import org.apache.http.HttpStatus;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * <p>
 * 预约记录表 服务实现类
 * </p>
 *
 * @author jobob
 * @since 2019-03-21
 */
@Service
public class AppointmentServiceImpl extends ServiceImpl<AppointmentMapper, Appointment> implements IAppointmentService {

    @Autowired
    private AppointmentMapper appointmentMapper;

    @Autowired
    private CustomerMapper customerMapper;

    private IdGen idGen = IdGen.get();

    @Override
    public ResponseBean getOpenidAppointmentList(String openid, Integer pageNum, Integer pageSize) {
        ResponseBean responseBean = new ResponseBean();
        Page<Appointment> page = new Page<>();
        page.setCurrent(pageNum);
        page.setSize(pageSize);

        IPage<Appointment> openidAppendableList = appointmentMapper.getOpenidAppendableList(page, openid);
        responseBean.addSuccess(openidAppendableList);
        return responseBean;
    }

    @Override
    public ResponseBean addWxAppointment(String openid, String parameter) {
        ResponseBean responseBean = new ResponseBean();
        Appointment appointment = JSONObject.parseObject(parameter, Appointment.class);

        QueryWrapper<Customer> customerQueryWrapper = new QueryWrapper<>();
        customerQueryWrapper.eq("openid", openid);
        Customer customer = customerMapper.selectOne(customerQueryWrapper);

        appointment.setCustomerId(customer.getCustomerId());
        appointment.setAppointmentId(idGen.nextId() + "");
        appointment.setStatus(1);
        appointmentMapper.insert(appointment);
        responseBean.addSuccess("操作成功!");
        return responseBean;
    }

    @Override
    public ResponseBean deleteWxAppointment(String appointmentId) {
        ResponseBean responseBean = new ResponseBean();

        QueryWrapper<Appointment> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("appointment_id", appointmentId);
        Appointment appointment = appointmentMapper.selectOne(queryWrapper);
        if (null == appointment) {
            responseBean.addError(HttpStatus.SC_BAD_REQUEST, "未找到需要删除的数据");
            return responseBean;
        }

        // todo 一些删除校验

        UpdateWrapper<Appointment> updateWrapper = new UpdateWrapper<>();
        updateWrapper.set("status", -1);
        updateWrapper.eq("appointment_id", appointmentId);

        int rows = appointmentMapper.update(appointment, updateWrapper);
        if (rows < 1) {
            responseBean.addError(HttpStatus.SC_INTERNAL_SERVER_ERROR, "删数据失败");
            return responseBean;
        }

        return responseBean;
    }
}
