package com.example.wholeestate.service.impl;


import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.example.wholeestate.common.base.BaseController;
import com.example.wholeestate.common.resp.ResponseBean;
import com.example.wholeestate.common.uuid.IdGen;
import com.example.wholeestate.dao.BuildingDynamicMapper;
import com.example.wholeestate.dao.BuildingMapper;
import com.example.wholeestate.model.Building;
import com.example.wholeestate.model.BuildingDynamic;
import com.example.wholeestate.service.IBuildingDynamicService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.stereotype.Service;
import org.springframework.web.bind.ServletRequestDataBinder;

import javax.servlet.http.HttpServletRequest;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.time.Instant;
import java.time.LocalDateTime;
import java.time.ZoneId;
import java.util.Date;
import java.util.HashMap;
import java.util.List;

/**
 * <p>
 * 项目动态表 服务实现类
 * </p>
 *
 * @author jobob
 * @since 2019-03-21
 */
@Service
public class BuildingDynamicServiceImpl extends ServiceImpl<BuildingDynamicMapper, BuildingDynamic> implements IBuildingDynamicService {

    @Autowired
    private BuildingDynamicMapper buildingDynamicMapper;

    @Autowired
    private BuildingMapper buildingMapper;

    private IdGen idGen = IdGen.get();
    protected void initBinder(HttpServletRequest request, ServletRequestDataBinder binder) throws Exception {
        DateFormat df = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        CustomDateEditor editor = new CustomDateEditor(df, true);//true表示允许为空，false反之
        binder.registerCustomEditor(Date.class, editor);
    }
    @Override
    public ResponseBean iBuildingDynamicList(Integer pageNum,Integer pageSize, String name, String buildingId) {
        ResponseBean response= new ResponseBean();

        Page<BuildingDynamic> page = new Page<>();
        page.setSize(pageSize == null ? 10 : pageSize);
        page.setCurrent(pageNum == null ? 1 : pageNum);

        IPage<BuildingDynamic> buildingDynamic = buildingDynamicMapper.buildingDynamicList(page, name, buildingId);
        List<BuildingDynamic> buildingDynamicList=buildingDynamic.getRecords();

        HashMap hashMap= new HashMap<>();
        hashMap.put("list",buildingDynamicList);
        hashMap.put("total",buildingDynamic.getTotal());
        hashMap.put("pageNum",buildingDynamic.getCurrent());
        hashMap.put("pageSize",buildingDynamic.getSize());
        response.addSuccess(hashMap);
        return response;
    }

    @Override
    public ResponseBean iBuildingDynamicSelectId(String id) {
        ResponseBean response= new ResponseBean();
        BuildingDynamic buildingDynamicList= buildingDynamicMapper.iBuildingDynamicSelectId(id);
        response.addSuccess(buildingDynamicList);
        return response;
    }

    @Override
    public ResponseBean getWxBuildingDynamiceList(Integer pageNum, Integer pageSize) {
        ResponseBean responseBean = new ResponseBean();

        Page<BuildingDynamic> page = new Page<>();
        page.setCurrent(pageNum);
        page.setSize(pageSize);
        QueryWrapper<BuildingDynamic> buildingDynamicQueryWrapper = new QueryWrapper<>();
        buildingDynamicQueryWrapper.eq("status", "1");
        IPage<BuildingDynamic> buildingDynamicIPage = buildingDynamicMapper.selectPage(page, buildingDynamicQueryWrapper);
        List<BuildingDynamic> records = buildingDynamicIPage.getRecords();
        records.forEach(e -> {
            QueryWrapper<Building> buildingQueryWrapper = new QueryWrapper<>();
            buildingQueryWrapper.eq("building_id", e.getBuildingId());
            Building building = buildingMapper.selectOne(buildingQueryWrapper);
            e.setBuilding(building);
        });

        responseBean.addSuccess(buildingDynamicIPage);
        return responseBean;
    }

    @Override
    public ResponseBean getWxBuildingDynamiceInfo(String dynamicId) {
        ResponseBean responseBean = new ResponseBean();

        QueryWrapper<BuildingDynamic> buildingDynamicQueryWrapper = new QueryWrapper<>();
        buildingDynamicQueryWrapper.eq("dynamic_id", dynamicId);
        BuildingDynamic buildingDynamic = buildingDynamicMapper.selectOne(buildingDynamicQueryWrapper);
        responseBean.addSuccess(buildingDynamic);
        return responseBean;
    }

    @Override
    public ResponseBean buildingDynamicAdd(HashMap map) {
        ResponseBean responseBean= new ResponseBean<>();
        BuildingDynamic buildingDynamic= new BuildingDynamic();
        Date time = (Date)map.get("publishDate");
        Instant instant = time.toInstant();
        ZoneId zoneId = ZoneId.systemDefault();
        LocalDateTime localDateTime = instant.atZone(zoneId).toLocalDateTime();

        buildingDynamic.setDynamicId(idGen.nextId()+"");
        buildingDynamic.setBuildingId(map.get("buildingId")+"");
        buildingDynamic.setImgUrl((String) map.get("imgUrl"));
        buildingDynamic.setDesc(map.get("desc")+"");
        buildingDynamic.setUrl(map.get("url")+"");
        buildingDynamic.setTitle(map.get("title")+"");
        buildingDynamic.setPublishDate(localDateTime);
        buildingDynamic.setStatus(1);
        buildingDynamic.setCreateDate(LocalDateTime.now());

        buildingDynamicMapper.insertBuildingDynamic(buildingDynamic);
        responseBean.addSuccess("成功");
        return responseBean;
    }

    @Override
    public ResponseBean buildingDynamicDelete(String id) {
       ResponseBean responseBean= new ResponseBean<>();
        BuildingDynamic buildingDynamic= new BuildingDynamic();
        buildingDynamic.setDynamicId(id);
        buildingDynamic.setStatus(-1);
        QueryWrapper<BuildingDynamic> buildingDynamicQueryWrapper = new QueryWrapper<>();
        buildingDynamicQueryWrapper.eq("dynamic_id", id);
        buildingDynamicMapper.update(buildingDynamic,buildingDynamicQueryWrapper);
        responseBean.addSuccess("成功");
        return responseBean;
    }

    @Override
    public ResponseBean buildingDynamicUpdate(HashMap<Object, Object> map) {
        ResponseBean responseBean= new ResponseBean<>();
        BuildingDynamic buildingDynamic= new BuildingDynamic();

        Date time = (Date)map.get("publishDate");
        Instant instant = time.toInstant();
        ZoneId zoneId = ZoneId.systemDefault();
        LocalDateTime localDateTime = instant.atZone(zoneId).toLocalDateTime();

        buildingDynamic.setDynamicId(map.get("dynamicId")+"");
        buildingDynamic.setBuildingId(map.get("buildingId")+"");
        buildingDynamic.setImgUrl((String) map.get("imgUrl"));
        buildingDynamic.setDesc(map.get("desc")+"");
        buildingDynamic.setUrl(map.get("url")+"");
        buildingDynamic.setTitle(map.get("title")+"");
        buildingDynamic.setPublishDate(localDateTime);
        buildingDynamic.setStatus(1);
        buildingDynamic.setCreateDate(LocalDateTime.now());

        buildingDynamicMapper.buildingDynamicUpdate(buildingDynamic);
        responseBean.addSuccess("成功");
        return responseBean;
    }


}
