package com.example.wholeestate.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.example.wholeestate.common.Constant;
import com.example.wholeestate.common.resp.ResponseBean;
import com.example.wholeestate.common.uuid.IdGen;
import com.example.wholeestate.dao.CustomerMapper;

import com.example.wholeestate.model.Customer;
import com.example.wholeestate.service.ICustomerService;
import com.example.wholeestate.utils.BeanTools;
import com.example.wholeestate.wx.mini.IWxMini;
import org.apache.http.HttpStatus;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.Date;
import java.util.HashMap;
import java.util.List;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author weiximei
 * @since 2019-03-20
 */
@Service
public class CustomerServiceImpl extends ServiceImpl<CustomerMapper, Customer> implements ICustomerService {

    @Autowired
    private CustomerMapper customerMapper;

    @Autowired
    private IWxMini iWxMini;

    private IdGen idGen = IdGen.get();

    @Override
    public ResponseBean customerList(Integer pageNum, Integer pageSize, String phone, Date beginDate, Date endDate, String name , String cardNo) {
        ResponseBean response= new ResponseBean();

        Page<Customer> page = new Page<>();
        page.setSize(pageSize == null ? 10 : pageSize);
        page.setCurrent(pageNum == null ? 1 : pageNum);
        IPage<Customer> customer= customerMapper.customerList(page,name,phone,beginDate,endDate,cardNo);
        List<Customer> customerList=customer.getRecords();

        HashMap hashMap= new HashMap<>();
        hashMap.put("list",customerList);
        hashMap.put("total",customer.getTotal());
        hashMap.put("pageNum",customer.getCurrent());
        hashMap.put("pageSize",customer.getSize());
        response.addSuccess(hashMap);
        return response;
    }

    @Override
    public ResponseBean customerSelectId(String id) {
        ResponseBean response= new ResponseBean();
        QueryWrapper<Customer> customer=new QueryWrapper<>();
        customer.lambda().eq(Customer::getStatus,1);
        customer.eq("customer_id", id);
        Customer customerList= customerMapper.selectOne(customer);
        response.addSuccess(customerList);
        return response;
    }

    @Override
    public ResponseBean registeredCustomer(String parameter) {
        ResponseBean responseBean = new ResponseBean();
        Customer customer = JSONObject.parseObject(parameter, Customer.class);
        customer.setCreateDate(LocalDateTime.now());
        customer.setStatus(1);
        customer.setHasReg(1);

        QueryWrapper<Customer> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("openid", customer.getOpenid());
        Customer selectOne = customerMapper.selectOne(queryWrapper);
        if (null == selectOne) {
            responseBean.addError("用户不存在！");
            return responseBean;
        }

        BeanTools.copyProperties(customer, selectOne);

        customerMapper.update(selectOne, queryWrapper);
        responseBean.addSuccess("操作成功！");
        return responseBean;
    }

    @Override
    public ResponseBean getWXCustomer(String openid) {
        ResponseBean responseBean = new ResponseBean();
        QueryWrapper<Customer> customerQueryWrapper = new QueryWrapper<>();
        customerQueryWrapper.eq("openid", openid);
        Customer customer = customerMapper.selectOne(customerQueryWrapper);
        if (null == customer) {
            responseBean.addError(Constant.NOT_USER, "用户不存在!");
            return responseBean;
        }

        responseBean.addSuccess(customer);
        return responseBean;
    }

    @Override
    public ResponseBean wxOpenid(String code) {
        ResponseBean responseBean = new ResponseBean();
        String openid = iWxMini.getOpenid(code);

        QueryWrapper<Customer> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("openid", openid);
        Customer customer = customerMapper.selectOne(queryWrapper);
        if (null != customer) {
            responseBean.addSuccess(customer);
            return responseBean;
        }

        customer = new Customer();
        customer.setCustomerId(idGen.nextId() + "");
        customer.setCreateDate(LocalDateTime.now());
        customer.setOpenid(openid);
        customer.setHasReg(0);

        customerMapper.insert(customer);

        responseBean.addSuccess(customer);
        return responseBean;
    }

    @Override
    public ResponseBean updateCustomer(String parameter) {
        ResponseBean responseBean = new ResponseBean();
        Customer customer = JSONObject.parseObject(parameter, Customer.class);

        UpdateWrapper<Customer> updateWrapper = new UpdateWrapper<>();
        updateWrapper.set("customer_name", customer.getCustomerName());
        updateWrapper.set("name", customer.getName());
        updateWrapper.set("phone", customer.getPhone());
        updateWrapper.set("id_num", customer.getIdNum());
        updateWrapper.set("remark", customer.getRemark());
        updateWrapper.eq("customer_id", customer.getCustomerId());

        int success = customerMapper.update(customer, updateWrapper);
        if (success < 1) {
            responseBean.addError(HttpStatus.SC_INTERNAL_SERVER_ERROR, "更新用户信息失败");
        }

        return responseBean;
    }
}
